import numpy as np
from .object_detection_prediction import ObjectDetectionPrediction as ObjectDetectionPrediction
from .object_detection_results import ObjectDetectionResults as ObjectDetectionResults
from _typeshed import Incomplete
from edgeiq import bounding_box as bounding_box
from edgeiq._constants import SupportedPurposes as SupportedPurposes
from edgeiq._production_client import PRODUCTION_CLIENT as PRODUCTION_CLIENT
from edgeiq._utils import draw_text_with_background as draw_text_with_background
from edgeiq.base_service import BaseService as BaseService
from edgeiq.engine_accelerator import Engine as Engine
from edgeiq.model_config import ModelConfig as ModelConfig
from edgeiq.processing import ObjectDetectionProcessor as ObjectDetectionProcessor
from edgeiq.processing.object_detection.object_detection import PostProcessBatchT as PostProcessBatchT, PostProcessT as PostProcessT, PreProcessBatchT as PreProcessBatchT, PreProcessT as PreProcessT
from typing import Any

SUPPORTED_ENGINES: Incomplete

class ObjectDetection(BaseService[ObjectDetectionProcessor]):
    def __init__(self, model_id: str, model_config: ModelConfig | None = None, pre_process: PreProcessT | None = None, pre_process_batch: PreProcessBatchT | None = None, post_process: PostProcessT | None = None, post_process_batch: PostProcessBatchT | None = None) -> None: ...
    def detect_objects(self, image: np.ndarray, confidence_level: float = 0.3, overlap_threshold: float = 0.3) -> ObjectDetectionResults: ...
    def detect_objects_batch(self, images: list[np.ndarray], confidence_level: float = 0.3, overlap_threshold: float = 0.3) -> list[ObjectDetectionResults]: ...
    def publish_analytics(self, results: ObjectDetectionResults, tag: Any = None, **kwargs): ...

def markup_image(image: np.ndarray, predictions: list[ObjectDetectionPrediction], show_labels: bool = True, show_confidences: bool = True, colors: list[tuple[int, int, int]] | None = None, line_thickness: int = 2, font_size: float = 0.5, font_thickness: int = 2, background_padding: int = 10) -> np.ndarray: ...
def overlay_transparent_boxes(image: np.ndarray, predictions: list[ObjectDetectionPrediction], alpha: float = 0.5, colors: list[tuple[int, int, int]] | None = None, show_labels: bool = False, show_confidences: bool = False): ...
def blur_objects(image: np.ndarray, predictions: list[ObjectDetectionPrediction]) -> np.ndarray: ...
def filter_predictions_by_label(predictions: list[ObjectDetectionPrediction], label_list: list[str]) -> list[ObjectDetectionPrediction]: ...
def filter_predictions_by_area(predictions: list[ObjectDetectionPrediction], min_area_thresh: float) -> list[ObjectDetectionPrediction]: ...
